;; Generated package description from yasnippet.el
(define-package "yasnippet" "0.13.0" "Yet another snippet extension for Emacs." '((cl-lib "0.5")) :url "http://github.com/joaotavora/yasnippet" :keywords '("convenience" "emulation"))
